==> rsserpent_rev-0.1.4.tar.gz: rsserpent_rev-0.1.4/README.md <==
<p align="center">

<img alt="RSSerpent" src="./docs/__asset__/logo-200.png" width="250" />
</p>

[![python: 3.10.0+](https://img.shields.io/badge/python->=3.10.0-blue.svg)](https://www.python.org/downloads/)
[![code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![mypy: checked](https://img.shields.io/badge/mypy-checked-blue.svg)](https://github.com/python/mypy)

[![pypi: version](https://img.shields.io/pypi/v/rsserpent)](https://pypi.org/project/rsserpent/)
[![pypi downloads: per month](https://img.shields.io/pypi/dm/rsserpent)](https://pypi.org/project/rsserpent/)
[![docker: version](https://img.shields.io/docker/v/queensferry/rsserpent/latest?label=docker&sort=semver)](https://hub.docker.com/r/queensferry/rsserpent)
[![docker: image size](https://img.shields.io/docker/image-size/queensferry/rsserpent/master)](https://hub.docker.com/r/queensferry/rsserpent)

[![github test status](https://img.shields.io/github/workflow/status/RSSerpent-Rev/RSSerpent/Test?label=test&logo=github&message=passed)](https://github.com/RSSerpent-Rev/RSSerpent/actions/workflows/test.yaml)
[![codecov status](https://codecov.io/gh/RSSerpent-Rev/RSSerpent/branch/master/graph/badge.svg?token=FQZ5OWOQRO)](https://codecov.io/gh/RSSerpent-Rev/RSSerpent)
[![github docker status](https://img.shields.io/github/workflow/status/RSSerpent-Rev/RSSerpent/Build%20Docker%20Image?label=docker&logo=docker)](https://github.com/RSSerpent-Rev/RSSerpent/actions/workflows/docker.yaml)
[![netlify status](https://img.shields.io/netlify/8fc96574-bda5-4f06-9188-3673818b3eb5?label=docs&logo=netlify)](https://app.netlify.com/sites/rsserpent/deploys)

[![chat on telegram](https://img.shields.io/badge/chat%20on-telegram-blue.svg)](https://t.me/rsserpent_rev)

> This snake helps you reconnect the Web, with RSS feeds!

RSSerpent is an open-source software that creates [RSS](https://en.wikipedia.org/wiki/RSS) feeds for websites without them.

[English](https://github.com/RSSerpent-Rev/RSSerpent/blob/master/README.md) | [中文](https://github.com/RSSerpent-Rev/RSSerpent/blob/master/README.zh.md)

# Quick Start

- Official Instance: <https://rsserpent.imciel.com/>
- Documentation: <https://rsserpent-rev.github.io/RSSerpent/latest/>

# Thanks
The RSSerpent Project is heavily inspired by [RSSHub](https://github.com/DIYgod/RSSHub) 🎉 We pay the highest possible tribute to RSSHub & its maintainers.

Thanks to [RSSerpent](https://github.com/RSSerpent/RSSerpent) and [queensferryme](https://github.com/queensferryme), the original authors of the project.

<!-- ## Sponsors

<a href="https://linktr.ee/rss3" target="_blank"><img alt="rss3" src="https://ipfs.rss3.page/ipfs/QmUG6H3Z7D5P511shn7sB4CPmpjH5uZWu4m5mWX7U3Gqbu" width="200" /></a> -->

# People

The RSSerpent Project is original created by [@queensferry](https://github.com/queensferryme/), current maintain by [@EkkoG](https://github.com/EkkoG), supported by various [project members](https://github.com/orgs/RSSerpent-Rev/people) & [contributors](https://github.com/RSSerpent-Rev/RSSerpent/graphs/contributors).

==> rsserpent_rev-0.1.5.tar.gz: rsserpent_rev-0.1.5/README.md <==
<p align="center">

<img alt="RSSerpent" src="./docs/__asset__/logo-200.png" width="250" />
</p>

[![python: 3.10.0+](https://img.shields.io/badge/python->=3.10.0-blue.svg)](https://www.python.org/downloads/)
[![code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![mypy: checked](https://img.shields.io/badge/mypy-checked-blue.svg)](https://github.com/python/mypy)

[![pypi: version](https://img.shields.io/pypi/v/rsserpent-rev)](https://pypi.org/project/rsserpent-rev/)
[![pypi downloads: per month](https://img.shields.io/pypi/dm/rsserpent-rev)](https://pypi.org/project/rsserpent-rev/)

[![github test status](https://img.shields.io/github/actions/workflow/status/RSSerpent-Rev/RSSerpent/test.yaml?branch=master&label=test&logo=github&message=passed)](https://github.com/RSSerpent-Rev/RSSerpent/actions/workflows/test.yaml)
[![codecov status](https://codecov.io/gh/RSSerpent-Rev/RSSerpent/branch/master/graph/badge.svg?token=FQZ5OWOQRO)](https://codecov.io/gh/RSSerpent-Rev/RSSerpent)
[![github docker status](https://img.shields.io/github/actions/workflow/status/RSSerpent-Rev/RSSerpent/docker.yaml?label=docker&logo=docker)](https://github.com/RSSerpent-Rev/RSSerpent/actions/workflows/docker.yaml)


[![chat on telegram](https://img.shields.io/badge/chat%20on-telegram-blue.svg)](https://t.me/rsserpent_rev)

> This snake helps you reconnect the Web, with RSS feeds!

RSSerpent is an open-source software that creates [RSS](https://en.wikipedia.org/wiki/RSS) or [Atom](https://en.wikipedia.org/wiki/Atom_(web_standard)) feeds for websites without them.

[English](https://github.com/RSSerpent-Rev/RSSerpent/blob/master/README.md) | [中文](https://github.com/RSSerpent-Rev/RSSerpent/blob/master/README.zh.md)

# Quick Start

- Official Instance: <https://rsserpent.imciel.com/>
- Documentation: <https://rsserpent-rev.github.io/RSSerpent/latest/>

# Thanks

The RSSerpent Project is heavily inspired by [RSSHub](https://github.com/DIYgod/RSSHub) 🎉 We pay the highest possible tribute to RSSHub & its maintainers.

Thanks to [RSSerpent](https://github.com/RSSerpent/RSSerpent) and [queensferryme](https://github.com/queensferryme), the original authors of the project.

<!-- ## Sponsors

<a href="https://linktr.ee/rss3" target="_blank"><img alt="rss3" src="https://ipfs.rss3.page/ipfs/QmUG6H3Z7D5P511shn7sB4CPmpjH5uZWu4m5mWX7U3Gqbu" width="200" /></a> -->

# People

The RSSerpent Project is original created by [@queensferry](https://github.com/queensferryme/), current maintain by [@EkkoG](https://github.com/EkkoG), supported by various [project members](https://github.com/orgs/RSSerpent-Rev/people) & [contributors](https://github.com/RSSerpent-Rev/RSSerpent/graphs/contributors).
